import nodemailer from 'nodemailer';

export default async function handler(req, res) {
    if (req.method === 'POST') {
        const { name, number, venue, email, message } = req.body;

        // Create a Nodemailer transporter
        const transporter = nodemailer.createTransport({
            service: 'gmail',  // You can use any email provider like Gmail, SendGrid, etc.
            auth: {
                user: process.env.EMAIL_USER,  // Your email
                pass: process.env.EMAIL_PASS,  // Your email password or app password
            },
        });

        // Set up email data
        const mailOptions = {
            from: process.env.EMAIL_USER,  // Sender address
            to: email,  // Recipient email
            subject: `New message from ${name}`,
            html: `
                <h3>Contact Form Submission</h3>
                <p><strong>Name:</strong> ${name}</p>
                <p><strong>Number:</strong> ${number}</p>
                <p><strong>Venue:</strong> ${venue}</p>
                <p><strong>Email:</strong> ${email}</p>
                <p><strong>Message:</strong><br>${message}</p>
            `,
        };

        try {
            // Send email
            await transporter.sendMail(mailOptions);
            return res.status(200).json({ message: 'Email sent successfully!' });
        } catch (error) {
            console.error('Error sending email:', error);
            return res.status(500).json({ error: 'Error sending email' });
        }
    } else {
        return res.status(405).json({ error: 'Method Not Allowed' });
    }
}
