import { MdOutlineArrowOutward } from "react-icons/md";
import { TiStarFullOutline } from "react-icons/ti";
import { HiOutlineLocationMarker } from "react-icons/hi"
import { IoCallOutline, IoMailOutline, IoTimeOutline } from "react-icons/io5";
import { GoArrowRight } from "react-icons/go";
import { useState } from "react";
import Head from "next/head";
import Brandcrumbs from "@/components/Brandcrumbs";

export default function contact() {


    const [formData, setFormData] = useState({
        name: '',
        number: '',
        venue: '',
        email: '',
        message: ''
    });

    const handleChange = (e) => {
        const { name, value } = e.target;
        setFormData({
            ...formData,
            [name]: value
        });
    };

    const handleSubmit = async (e) => {
        e.preventDefault();

        try {
            const response = await fetch('/api/contact', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(formData),
            });

            if (response.ok) {
                alert('Your message has been sent!');
                setFormData({ name: '', number: '', venue: '', email: '', message: '' }); // Reset form
            } else {
                alert('There was an issue sending your message. Please try again.');
            }
        } catch (error) {
            alert('Error: ' + error.message);
        }
    };


    return <>
        <Head>
            <title>Contact Us</title>
        </Head>
        <div className="contact_page">
            {/* <div className="contact_title_main">
                <h2>CONTACT US</h2>
            </div> */}

            <Brandcrumbs title={'CONTACT US'} imges={'https://media.istockphoto.com/id/1370358685/photo/multicolored-pills-scattered-from-white-plastic-medicine-container.jpg?s=612x612&w=0&k=20&c=zknrVfCELovlvvXKrAlWKLnFLfkMQF8nh9k2d97pJkE='} />

            <div className="contact_page_cont">
                <div className="container">
                    <div className="contact_page_form">
                        <div className="leftside_contact_info">
                            <h3>Connect With Us For <br /> Your Healthcare Needs</h3>
                            <p className="leftside_pera">Reach out for support, feedback, or to schedule an appointment. Fill out the form, and we'll promptly assist you and confirm your visit with our healthcare professionals.</p>
                            <div className="talk_to_over">
                                <div className="talk_over_img_info">
                                    <div className="talkover_imgs">
                                        <img src="/img/avatar1.png" alt="" />
                                        <img src="/img/avatar2.png" alt="" />
                                        <img src="/img/avatar3.png" alt="" />
                                        <img src="/img/avatar4.png" alt="" />
                                    </div>
                                    <p>Talk to over 215 doctor</p>
                                </div>
                                <div className="talk_over_icon">
                                    <MdOutlineArrowOutward />
                                </div>
                            </div>
                            <div className="contact_us_rating_google">
                                <div className="contact_stars">
                                    <TiStarFullOutline />
                                    <TiStarFullOutline />
                                    <TiStarFullOutline />
                                    <TiStarFullOutline />
                                    <TiStarFullOutline />
                                </div>
                                <strong>(4.8)</strong>
                                <p>12k+ ratings on google</p>
                            </div>
                            <div className="four_address_cards">
                                <div className="four_address_card">
                                    <div className="four_address_card_svg">
                                        <HiOutlineLocationMarker />
                                    </div>
                                    <div>
                                        <h4>Address</h4>
                                        <p>7, Devam-4 Ind. Estate, Nr. Super City, Santej, Dist. Gandhinagar-382721 (Gujarat) INDIA.</p>
                                    </div>
                                </div>
                                <div className="four_address_card">
                                    <div className="four_address_card_svg">
                                        <IoCallOutline />
                                    </div>
                                    <div>
                                        <h4>Call Us</h4>
                                        <p>+91-9909931992</p>
                                    </div>
                                </div>
                                <div className="four_address_card">
                                    <div className="four_address_card_svg">
                                        <IoMailOutline />
                                    </div>
                                    <div>
                                        <h4>Send us a Mail</h4>
                                        <p>dellwich.mktg@gmail.com</p>
                                    </div>
                                </div>
                                <div className="four_address_card">
                                    <div className="four_address_card_svg">
                                        <IoTimeOutline />
                                    </div>
                                    <div>
                                        <h4>Opening Time</h4>
                                        <p>Mon-Thu: 8:00am - <br /> 5:00pm Fri: 8:00am - <br /> 1:00pm</p>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div className="rightside_contact_form">
                            <form onSubmit={handleSubmit}>
                                <h2>Get In Touch</h2>
                                <p>You can react us anytime</p>

                                <div className="rightside_contact_inputs">
                                    <div className="input-container">
                                        <input
                                            required
                                            id="name"
                                            type="text"
                                            name="name"
                                            value={formData.name}
                                            onChange={handleChange}
                                        />
                                        <label className="label" htmlFor="name">Full Name</label>
                                        <div className="underline"></div>
                                    </div>

                                    <div className="flex w-100 gap-1">
                                        <div className="input-container">
                                            <input
                                                required
                                                id="number"
                                                type="text"
                                                name="number"
                                                value={formData.number}
                                                onChange={handleChange}
                                            />
                                            <label className="label" htmlFor="number">Number</label>
                                            <div className="underline"></div>
                                        </div>
                                        <div className="input-container">
                                            <input
                                                required
                                                id="venue"
                                                type="text"
                                                name="venue"
                                                value={formData.venue}
                                                onChange={handleChange}
                                            />
                                            <label className="label" htmlFor="venue">Venue</label>
                                            <div className="underline"></div>
                                        </div>
                                    </div>

                                    <div className="input-container">
                                        <input
                                            required
                                            id="email"
                                            type="text"
                                            name="email"
                                            value={formData.email}
                                            onChange={handleChange}
                                        />
                                        <label className="label" htmlFor="email">Email</label>
                                        <div className="underline"></div>
                                    </div>

                                    <div className="input-container">
                                        <textarea
                                            required
                                            id="message"
                                            name="message"
                                            rows={6}
                                            value={formData.message}
                                            onChange={handleChange}
                                        />
                                        <label className="label" htmlFor="message">Message</label>
                                        <div className="underline"></div>
                                    </div>

                                    <button type="submit">
                                        Submit <span><GoArrowRight /></span>
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
            <iframe src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d6172.069344779884!2d72.46879668365436!3d23.099497513098424!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x395e9d5932a82ad5%3A0xda7f3ffc2045ddea!2sDellwich%20Lifescience%20LLP!5e0!3m2!1sen!2sin!4v1735045085325!5m2!1sen!2sin" allowFullScreen loading="lazy" referrerpolicy="no-referrer-when-downgrade"></iframe>
        </div>
    </>
}